#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-FHWwDNr69G3E05e3JJfB0K
key:                  glirc-2.41-FHWwDNr69G3E05e3JJfB0K
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  96192c86a45c1695cfbad32f0c850dda
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-FHWwDNr69G3E05e3JJfB0K
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.10-LscABpWdm1BFDWWVui0y8P
    async-2.2.6-9SkVXCaD6xtG9Q9oLNb0PF
    attoparsec-0.14.4-FNfFcxBCxLE3gVrmuo10Xu base-4.18.2.1
    base64-bytestring-1.2.1.0-3sV69hgoSWS1a2SgImTi0f
    bytestring-0.11.5.3 config-schema-1.3.0.0-9FIbCHmrfZtDTB8oE1bkEU
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-SfI0TjmA751xrt8y1WB3r directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-IJZEVYiDYbWGnX9BjgMipL
    githash-0.1.7.0-4wPuFnraheY8jlF72d4CGw
    hashable-1.4.7.0-IundBnRd4VH238tCbJShYq
    hookup-0.8-DGBoERyeEu77P1G3N0dtNe
    irc-core-2.13-9O8KZ0ipNtj8UqwJCGJHIR
    kan-extensions-5.2.8-LpNGz8Mv7YILfk3URcLCog
    lens-5.3.5-2rHF7qT7ygdHhmCf5McDK3
    network-3.1.4.0-Dw21gcQ0zRE10R3MPv5g8s
    psqueues-0.2.8.3-4z5oLkFBQAi1SzIMqoY4W1
    random-1.2.1.3-8T7wlm0rQ0t5wVCdHG7g6D
    regex-tdfa-1.3.2.6-GDn4kuvUrdrF2TzBzindmK
    semigroupoids-6.0.2-Kh9B8Cq9iBP2z7fdzOg3qB
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-Dfig2CH9X0Q5cI9bXZXAQ9
    unix-2.8.4.0 unordered-containers-0.2.21-6KS41JVoQWZ5mM86HX5ZiJ
    vector-0.13.2.0-CGL8pnIxGMbHvZ63ZDtObP
    vty-6.2-HZ8pn0VIyqM9bjd1ccInJp

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

